@@ -38,7 +38,7 @@ except ImportError:
 
 __all__ = ['Freezer']
 
-VERSION = '0.8'
+VERSION = '0.9'
 
 
 class MissingURLGeneratorWarning(Warning):
@@ -302,13 +302,18 @@ class Freezer(object):
     def serve(self, **options):
         """Run an HTTP server on the result of the build.
 
-        :param options: passed to ``app.run()``.
+        :param options: passed to :meth:`flask.Flask.run`.
         """
         app = self.make_static_app()
         script_name = self._script_name()
         app.wsgi_app = script_name_middleware(app.wsgi_app, script_name)
         app.run(**options)
 
+    def run(self, **options):
+        """Same as :meth:`serve` but calls :meth:`freeze` before serving."""
+        self.freeze()
+        self.serve(**options)
+
     def make_static_app(self):
         """Return a Flask application serving the build destination."""
         root = os.path.join(
